@@ -55,19 +55,18 @@ attachments region.
   (let (ret max)
     (save-excursion
       (beginning-of-line)
-      (setq ret (mew-count-lines (1+ (mew-attach-begin)) (point)))
+      (setq ret (count-lines (1+ (mew-attach-begin)) (point)))
       (goto-char (point-max))
       (beginning-of-line)
-      (setq max (mew-count-lines (1+ (mew-attach-begin)) (point)))
+      (setq max (count-lines (1+ (mew-attach-begin)) (point)))
       (if (or (= ret max) (= ret (1- max))) -1 ret))))
 
-
 (defun mew-attach-line-lastp ()
   (let ((here (point)))
     (save-excursion
       (goto-char (point-max))
       (beginning-of-line)
-      (= (mew-count-lines here (point)) 2))))
+      (= (count-lines here (point)) 2))))
 
 (defun mew-attach-move-onto-file ()
   (end-of-line)
@@ -160,6 +159,17 @@ attachments region.
       (re-search-forward (concat "^....." numreg " ") nil t)
       (mew-attach-move-onto-file))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Dialog
+;;;
+
+(defun mew-substitute-for-attach (msg)
+  (substitute-command-keys (concat "\\<mew-draft-attach-map>" msg)))
+
+(defun mew-message-for-attach (msg)
+  (message "%s" (mew-substitute-for-attach msg)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; commands
@@ -326,11 +336,11 @@ attachments region.
 	(setq ct (mew-content-type (mew-tinfo-get-case)))
 	(cond
 	 ((string= ct mew-ct-txt)
-	  (setq msg (substitute-command-keys
-		     "Attached as text. Type '\\<mew-draft-attach-map>\\[mew-attach-toggle]' to toggle text to binary")))
+	  (setq msg (mew-substitute-for-attach
+		     "Attached as text. Type '\\[mew-attach-toggle]' to toggle text to binary")))
 	 ((string= ct mew-ct-apo)
-	  (setq msg (substitute-command-keys
-		     "Attached as binary. Type '\\<mew-draft-attach-map>\\[mew-attach-toggle]' to toggle binary to text")))))
+	  (setq msg (mew-substitute-for-attach
+		     "Attached as binary. Type '\\[mew-attach-toggle]' to toggle binary to text")))))
       (setq mew-encode-syntax
 	    (mew-syntax-insert-entry
 	     mew-encode-syntax 
@@ -338,7 +348,7 @@ attachments region.
 	     (mew-encode-syntax-single tofile (list ct) nil nil nil 'cdp)))
       (mew-encode-syntax-print mew-encode-syntax)
       (if mew-attach-move-next-after-copy (mew-attach-next))
-      (if msg (message msg)))))
+      (if msg (message "%s" msg)))))
 
 (defun mew-attach-link (&optional from to)
   "Link a file with a symbolic link on '.' in attachments.
@@ -440,18 +450,16 @@ on '.' in attachments."
 	      (progn
 		(if (not (y-or-n-p "Are you ready? "))
 		    (message "Nothing is recoded")
-		  (message
-		   (substitute-command-keys
-		    "Type '\\[keyboard-quit]' to finish recording..."))
+		  (mew-message-for-attach
+		   "Type '\\[keyboard-quit]' to finish recording...")
 		  (mew-plet
 		   (apply 'call-process
 			  (nth 0 mew-prog-audio2)
 			  nil t nil
 			  (nth 1 mew-prog-audio2)))))
 	    (quit
-	     (message
-	      (substitute-command-keys
-	       "Type '\\[keyboard-quit]' to finish recording...done"))
+	     (mew-message-for-attach
+	      "Type '\\[keyboard-quit]' to finish recording...done")
 	     (setq recorded t)
 	     (mew-flet
 	      (write-region (point-min) (point-max) filepath nil 'no-msg)))))
