@@ -15,9 +15,9 @@
 (defvar mew-prog-enriched 'mew-mime-text/enriched)
 (defvar mew-prog-text     'mew-mime-text/plain)
 (defvar mew-prog-audio
-  `(,mew-prog-shell (,mew-prog-shell-arg "cat - > /dev/audio") nil))
+  `(,shell-file-name (,shell-command-switch "cat - > /dev/audio") nil))
 (defvar mew-prog-audio2
-  `(,mew-prog-shell (,mew-prog-shell-arg "cat < /dev/audio") nil))
+  `(,shell-file-name (,shell-command-switch "cat < /dev/audio") nil))
 (defvar mew-prog-image           '(mew-mime-image/* mew-mime-image/*-ext))
 (defvar mew-prog-iges nil)
 (defvar mew-prog-vrml nil)
@@ -41,6 +41,7 @@
 				   mew-mime-application/msexcel-ext))
 (defvar mew-prog-mspowerpoint    '(mew-mime-application/mspowerpoint
 				   mew-mime-application/mspowerpoint-ext))
+(defvar mew-prog-visio           'mew-mime-application/octet-stream)
 
 ;;;
 ;;; Text/Html, Application/Xml, Image
