@@ -2,7 +2,7 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Mar 23, 1994
-;; Revised: Jul 24 2003
+;; Revised: Jun  1, 2004
 
 ;;; Commentary:
 
@@ -19,7 +19,7 @@
 ;;; Mew version
 ;;;
 
-(defconst mew-version-number "3.3"
+(defconst mew-version-number "4.0.65"
   "Version number for this version of Mew.")
 (defconst mew-version (format "Mew version %s" mew-version-number)
   "Version string for this version of Mew.")
@@ -53,7 +53,7 @@
 ;;;
 
 (defvar mew-debug nil
-  "'decode, 'encode, 'net, 'pgp, 'thread, 'sort, 'pack, t for all.")
+  "'decode, 'encode, 'net, 'pgp, 'thread, 'sort, t for all.")
 (defsubst mew-debug (category)
   (or (eq mew-debug t) (eq mew-debug category)))
 
@@ -93,13 +93,13 @@ considered reversed."
   (let* ((auto (if arg (not mew-auto-get) mew-auto-get))
 	 (case mew-case-input)
 	 (proto (mew-proto case))
-	 inbox)
+	 inbox case:inbox)
     (if auto
 	(mew-summary-scan-boot proto case)
       ;; see also mew-summary-retrieve
       (setq inbox (mew-proto-inbox-folder proto case))
-      (setq inbox (mew-folder-case-folder case inbox))
-      (mew-summary-visit-folder inbox 'goend 'no-ls))
+      (setq case:inbox (mew-case-folder case inbox))
+      (mew-summary-visit-folder case:inbox 'goend))
     (setq mew-inbox-window (current-window-configuration))))
 
 ;;;###autoload
@@ -176,7 +176,8 @@ CONTINUE, YANK-ACTION and SEND-ACTIONS are ignored."
 	  (mew-mark-init)
 	  (mew-config-init)
 	  (mew-rotate-log-files mew-smtp-log-file)
-	  (mew-rotate-log-files mew-nntp-log-file))
+	  (mew-rotate-log-files mew-nntp-log-file)
+	  (mew-rotate-log-files mew-refile-log-file))
       (error
        (set-buffer (generate-new-buffer mew-buffer-debug))
        (goto-char (point-max))
@@ -185,29 +186,7 @@ CONTINUE, YANK-ACTION and SEND-ACTIONS are ignored."
        (set-buffer-modified-p nil)
        (setq buffer-read-only t)
        ;; cause an error again
-       (error "Mew found some errors above.")))))
-
-(defun mew-touch-folder-check ()
-  "Create dummy file and check modification of directory timestamps.
-If operating system cannot update directory timestamp,
-set mew-touch-folder-p to t"
-  (interactive)
-  (when mew-touch-folder-check-enabled-p
-    (let* ((dir (expand-file-name mew-mail-path))
-	   (file (expand-file-name mew-summary-touch-file dir))
-	   (time1 (mew-file-get-time dir))
-	   time2 curtime)
-      (when (file-writable-p file)
-	(setq curtime (current-time))
-	(if (and (equal (nth 1 curtime) (nth 1 time1))
-		 (equal (nth 0 curtime) (nth 0 time1)))
-	    (sleep-for 1))
-	(write-region "touched by Mew.(test)" nil file nil 'no-msg)
-	(mew-delete-file file)
-	(setq time2 (mew-file-get-time dir))
-	(if (equal time1 time2)
-	    ;; this system cannot update directory timestamp.
-	    (setq mew-touch-folder-p t))))))
+       (error "Mew found some errors above")))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -235,7 +214,7 @@ If executed with '\\[universal-argument]', information about local folders is
 also updated in addition to that of Addrbook. 
 If executed with '1', information about local folders is updated.
 If executed with '2', information about newsgroups is updated.
-If executed with '3', information about IMAP folders is updated. "
+If executed with '3', information about IMAP folders is updated."
   (interactive "P")
   (message "Updating status...")
   (cond
@@ -255,7 +234,6 @@ If executed with '3', information about IMAP folders is updated. "
     (mew-folder-init mew-inbox-folders)
     (mew-folder-init mew-queue-folders)
     (mew-folder-init mew-postq-folders)
-    (mew-touch-folder-check)
     (mew-refile-setup)
     (mew-addrbook-setup)
     (mew-scan-setup)
@@ -267,7 +245,8 @@ If executed with '3', information about IMAP folders is updated. "
     (mew-theme-setup)
     (mew-biff-setup)
     (mew-ct-setup)))
-  (message "Updating status...done"))
+  (unless (or (eq arg 2) (eq arg 3))
+    (message "Updating status...done")))
 
 (defvar mew-mime-content-type-list nil
   "Candidate of Content-Type: when CT: is changed in draft buffer.")
@@ -499,7 +478,7 @@ the lower window is not zero, switch to the buffer."
 (defun mew-temp-dir-init ()
   "Setting temporary directory for Mew.
 mew-temp-file must be local and readable for the user only
-for privacy/speed reasons. "
+for privacy/speed reasons."
   (setq mew-temp-dir (make-temp-name mew-temp-file-initial))
   (mew-make-directory mew-temp-dir)
   (set-file-modes mew-temp-dir mew-folder-mode)
@@ -522,32 +501,28 @@ It is typically called by kill-emacs-hook."
 
 (defvar mew-regex-msg-show nil)
 (defvar mew-regex-msg-or-part nil)
-(defvar mew-regex-msg-mark nil)
 (defvar mew-regex-msg-review nil)
-(defvar mew-regex-msg-valid-review nil)
 (defvar mew-regex-msg-delete nil)
 (defvar mew-regex-attach-beg nil)
 (defvar mew-regex-attach-end nil)
 (defvar mew-regex-my-address-list nil)
 (defvar mew-regex-ignore-folders nil)
+(defvar mew-regex-thread-separator nil)
 
 (defsubst mew-mark-regex (mark)
-  (concat mew-regex-msg (regexp-quote (char-to-string mark))))
-
-(defsubst mew-mark-valid-regex (mark)
-  (concat mew-regex-msg-valid (regexp-quote (char-to-string mark))))
+  (concat "^" (regexp-quote (char-to-string mark))))
 
 (defsubst mew-mark-list-regex (mark-list)
-  (concat mew-regex-msg "[" (mapconcat 'char-to-string mark-list "") "]"))
+  (concat "^" "[" (mapconcat 'char-to-string mark-list "") "]"))
 
 (defun mew-regex-setup ()
   (setq mew-eoh (format "^\\(%s\\|\\)$" (regexp-quote mew-header-separator)))
-  (setq mew-regex-msg-show (mew-mark-list-regex (cons ?  mew-mark-show-list)))
+  (setq mew-regex-msg-show (mew-mark-list-regex (cons 32 mew-mark-show-list)))
   (setq mew-regex-msg-or-part (concat mew-regex-msg-show "\\|" mew-regex-part))
-  (setq mew-regex-msg-mark (concat mew-regex-msg mew-regex-mark))
   (setq mew-regex-msg-review (mew-mark-regex mew-mark-review))
-  (setq mew-regex-msg-valid-review (mew-mark-valid-regex mew-mark-review))
   (setq mew-regex-msg-delete (mew-mark-regex mew-mark-delete))
+  (setq mew-regex-thread-separator
+	(concat "^" (regexp-quote mew-thread-separator)))
   (setq mew-regex-attach-beg
 	(concat "^" mew-draft-attach-boundary-beg "$"))
   (setq mew-regex-attach-end
@@ -608,7 +583,7 @@ It is typically called by kill-emacs-hook."
 	(save-excursion
 	  (set-buffer buf)
 	  (when (mew-summary-or-virtual-p)
-	    (mew-summary-kill-subprocess)
+	    (mew-summary-kill-subprocess 'no-msg)
 	    (setq obuf (mew-local-buffer-name folder))
 	    ;; xxx should kill pop's buffer...
 	    (mew-remove-buffer obuf))
@@ -720,6 +695,7 @@ Mew remain, so you can resume with buffer operations."
 (require 'mew-nntp)
 (require 'mew-nntp2)
 (require 'mew-imap)
+(require 'mew-imap2)
 (require 'mew-config)
 (require 'mew-auth)
 
